Skip to contents

Return paths for mnirs example files

Usage

example_mnirs(file = NULL)

Arguments

file

A character string (partially) matching the name of a data file. If NULL, returns a vector of all available file names.

Value

File paths for selected example files stored in this package.

Examples

## lists all files
example_mnirs()
#> [1] "artinis_intervals.xlsx"  "moxy_intervals.csv"     
#> [3] "moxy_ramp.xlsx"          "train.red_intervals.csv"
#> [5] "vo2master_moxyunit.xlsx"

## partial matching will error if matches multiple
## example_mnirs("moxy")
#> Error in `example_mnirs()`:
#> ! Multiple files match "moxy":
#> ℹ Matching files:"moxy_ramp.xlsx" and "moxy_intervals.csv"

example_mnirs("moxy_ramp")
#> [1] "/home/runner/work/_temp/Library/mnirs/extdata/moxy_ramp.xlsx"