Generic methods defined for objects returned from process_kinetics().
Arguments
- x
Object of class
mnirs.kineticsreturned fromprocess_kinetics().- ...
Additional arguments.
plot_coefsplot_coefs = TRUEwill display kinetics coefficients at the top left of the plot.plot_diagnosticsplot_diagnostics = TRUEwill display kinetics model diagnostic metrics at the bottom right of the plot.plot_residualsplot_diagnostics = TRUEwill display kinetics model residuals along the bottom of the plot. Residual values are correctly scaled about the zero dotted line