Skip to contents

Custom mNIRS colour palette

Usage

palette_mnirs(n = NULL)

Arguments

n

A character or numeric vector specifying either the name or the number in order of colours to return.

Value

Named or unnamed character vector of hex colours.

Examples

if (FALSE) { # \dontrun{
scales::show_col(palette_mnirs())
scales::show_col(palette_mnirs(2))
scales::show_col(palette_mnirs(c("red", "orange")))
} # }